==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkDataSetToDataObjectFilter.java <==
// java wrapper for vtkDataSetToDataObjectFilter object
//

package vtk;
import vtk.*;

public class vtkDataSetToDataObjectFilter extends vtkDataObjectAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGeometry_2(int id0);
  public void SetGeometry(int id0)
    { SetGeometry_2(id0); }

  private native int GetGeometry_3();
  public int GetGeometry()
    { return GetGeometry_3(); }

  private native void GeometryOn_4();
  public void GeometryOn()
    { GeometryOn_4(); }

  private native void GeometryOff_5();
  public void GeometryOff()
    { GeometryOff_5(); }

  private native void SetTopology_6(int id0);
  public void SetTopology(int id0)
    { SetTopology_6(id0); }

  private native int GetTopology_7();
  public int GetTopology()
    { return GetTopology_7(); }

  private native void TopologyOn_8();
  public void TopologyOn()
    { TopologyOn_8(); }

  private native void TopologyOff_9();
  public void TopologyOff()
    { TopologyOff_9(); }

  private native void SetFieldData_10(int id0);
  public void SetFieldData(int id0)
    { SetFieldData_10(id0); }

  private native int GetFieldData_11();
  public int GetFieldData()
    { return GetFieldData_11(); }

  private native void FieldDataOn_12();
  public void FieldDataOn()
    { FieldDataOn_12(); }

  private native void FieldDataOff_13();
  public void FieldDataOff()
    { FieldDataOff_13(); }

  private native void SetPointData_14(int id0);
  public void SetPointData(int id0)
    { SetPointData_14(id0); }

  private native int GetPointData_15();
  public int GetPointData()
    { return GetPointData_15(); }

  private native void PointDataOn_16();
  public void PointDataOn()
    { PointDataOn_16(); }

  private native void PointDataOff_17();
  public void PointDataOff()
    { PointDataOff_17(); }

  private native void SetCellData_18(int id0);
  public void SetCellData(int id0)
    { SetCellData_18(id0); }

  private native int GetCellData_19();
  public int GetCellData()
    { return GetCellData_19(); }

  private native void CellDataOn_20();
  public void CellDataOn()
    { CellDataOn_20(); }

  private native void CellDataOff_21();
  public void CellDataOff()
    { CellDataOff_21(); }

  public vtkDataSetToDataObjectFilter() { super(); }

  public vtkDataSetToDataObjectFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-armv6h.pkg.tar.xz: vtk/vtkDataSetToDataObjectFilter.java <==
// java wrapper for vtkDataSetToDataObjectFilter object
//

package vtk;
import vtk.*;

public class vtkDataSetToDataObjectFilter extends vtkDataObjectAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGeometry_2(int id0);
  public void SetGeometry(int id0)
    { SetGeometry_2(id0); }

  private native int GetGeometry_3();
  public int GetGeometry()
    { return GetGeometry_3(); }

  private native void GeometryOn_4();
  public void GeometryOn()
    { GeometryOn_4(); }

  private native void GeometryOff_5();
  public void GeometryOff()
    { GeometryOff_5(); }

  private native void SetTopology_6(int id0);
  public void SetTopology(int id0)
    { SetTopology_6(id0); }

  private native int GetTopology_7();
  public int GetTopology()
    { return GetTopology_7(); }

  private native void TopologyOn_8();
  public void TopologyOn()
    { TopologyOn_8(); }

  private native void TopologyOff_9();
  public void TopologyOff()
    { TopologyOff_9(); }

  private native void SetFieldData_10(int id0);
  public void SetFieldData(int id0)
    { SetFieldData_10(id0); }

  private native int GetFieldData_11();
  public int GetFieldData()
    { return GetFieldData_11(); }

  private native void FieldDataOn_12();
  public void FieldDataOn()
    { FieldDataOn_12(); }

  private native void FieldDataOff_13();
  public void FieldDataOff()
    { FieldDataOff_13(); }

  private native void SetPointData_14(int id0);
  public void SetPointData(int id0)
    { SetPointData_14(id0); }

  private native int GetPointData_15();
  public int GetPointData()
    { return GetPointData_15(); }

  private native void PointDataOn_16();
  public void PointDataOn()
    { PointDataOn_16(); }

  private native void PointDataOff_17();
  public void PointDataOff()
    { PointDataOff_17(); }

  private native void SetCellData_18(int id0);
  public void SetCellData(int id0)
    { SetCellData_18(id0); }

  private native int GetCellData_19();
  public int GetCellData()
    { return GetCellData_19(); }

  private native void CellDataOn_20();
  public void CellDataOn()
    { CellDataOn_20(); }

  private native void CellDataOff_21();
  public void CellDataOff()
    { CellDataOff_21(); }

  public vtkDataSetToDataObjectFilter() { super(); }

  public vtkDataSetToDataObjectFilter(long id) { super(id); }
  public native long   VTKInit();

}
